//
// MessagePack for C++ deserializing routine
//
// Copyright (C) 2018 KONDO Takatoshi
//
//    Distributed under the Boost Software License, Version 1.0.
//    (See accompanying file LICENSE_1_0.txt or copy at
//    http://www.boost.org/LICENSE_1_0.txt)
//
#ifndef MSGPACK_PARSE_HPP
#define MSGPACK_PARSE_HPP

#include "msgpack/parse_decl.hpp"

#include "msgpack/v2/parse.hpp"
#include "msgpack/v3/parse.hpp"

#endif // MSGPACK_PARSE_HPP
